| Title: | Model Wrappers for Discriminant Analysis |
|---|---|
| Description: | Bindings for additional classification models for use with the 'parsnip' package. Models include flavors of discriminant analysis, such as linear (Fisher (1936) <doi:10.1111/j.1469-1809.1936.tb02137.x>), regularized (Friedman (1989) <doi:10.1080/01621459.1989.10478752>), and flexible (Hastie, Tibshirani, and Buja (1994) <doi:10.1080/01621459.1994.10476866>), as well as naive Bayes classifiers (Hand and Yu (2007) <doi:10.1111/j.1751-5823.2001.tb00465.x>). |
| Authors: | Emil Hvitfeldt [aut, cre] (ORCID: <https://orcid.org/0000-0002-0679-1945>), Max Kuhn [aut] (ORCID: <https://orcid.org/0000-0003-2402-136X>), Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>) |
| Maintainer: | Emil Hvitfeldt <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.1.0.9000 |
| Built: | 2026-05-14 15:32:45 UTC |
| Source: | https://github.com/tidymodels/discrim |
discrim_regularized() describes the effect of frac_common_cov() and
frac_identity(). smoothness() is an alias for the adjust parameter in
stats::density().
frac_common_cov(range = c(0, 1), trans = NULL) frac_identity(range = c(0, 1), trans = NULL) smoothness(range = c(0.5, 1.5), trans = NULL)frac_common_cov(range = c(0, 1), trans = NULL) frac_identity(range = c(0, 1), trans = NULL) smoothness(range = c(0.5, 1.5), trans = NULL)
range |
A two-element vector holding the defaults for the smallest and largest possible values, respectively. |
trans |
A |
These parameters can modulate a RDA model to go between linear and quadratic class boundaries.
A function with classes "quant_param" and "param"
frac_common_cov()frac_common_cov()
Parabolic class boundary data
These data were simulated. There are two correlated predictors and two classes in the factor outcome.
parabolic |
a data frame |
if (rlang::is_installed("ggplot2")) { data(parabolic) library(ggplot2) ggplot(parabolic, aes(x = X1, y = X2, col = class)) + geom_point(alpha = .5) + theme_bw() }if (rlang::is_installed("ggplot2")) { data(parabolic) library(ggplot2) ggplot(parabolic, aes(x = X1, y = X2, col = class)) + geom_point(alpha = .5) + theme_bw() }